Box is written and maintained by Chris Griffith chris@cdgriffith.com.

A big thank you to everyone that has helped! From PRs to suggestions and bug
reporting, all input is greatly appreciated!

Code contributions:

- Alexandre Decan (AlexandreDecan)
- dhilipsiva (dhilipsiva)
- MAA (FooBarQuaxx)
- Jiang Chen (criver)
- Matan Rosenberg (matan129)
- Matt Wisniewski (polishmatt)
- Martijn Pieters (mjpieters)
- (sdementen)
- Brandon Gomes (bhgomes)
- Stretch (str3tch)
- (pwwang)
- Harun Tuncay (haruntuncay)
- Jeremiah Lowin (jlowin)
- (jandelgado)
- Jonas Irgens Kylling (jkylling)
- Bruno Rocha (rochacbruno)
- Noam Graetz (NoamGraetz2)

Suggestions and bug reporting:

- JiuLi Gao (gaojiuli)
- Jürgen Hermann (jhermann)
- tilkau [reddit]
- Jumpy89 [reddit]
- can_dry [reddit]
- spidyfan21 [reddit]
- Casey Havenor (chavenor)
- wim glenn (wimglenn)
- Vishwas B Sharma (csurfer)
- John Benediktsson (mrjbq7)
- delirious_lettuce [reddit]
- Justin Iso (justiniso)
- (crazyplum)
- Christopher Toth (ctoth)
- RickS (rshap91)
- askvictor [Hacker News]
- wouter bolsterlee (wbolster)
- Mickaël Thomas (mickael9)
- (pwwang)
- (richieadler)
- V.Anh Tran (tranvietanh1991)
- (ipcoder)
- (cebaa)
- (deluxghost)
- Nikolay Stanishev (nikolaystanishev)
- Craig Quiter (crizCraig)
- Michael Stella (alertedsnake)
- (FunkyLoveCow)
- Kevin Cross (kevinhcross)
- (Patrock)
- Tim Gates (timgates42)
- (iordanivanov)
- Steven McGrath (SteveMcGrath)
- Marcelo Huerta (richieadler)
- Wenbo Zhao (zhaowb)
- Yordan Ivanov (iordanivanov)
- Lei (NEOOOOOOOOOO)
- Pymancer
- Krishna Penukonda (tasercake)
- J Alan Brogan (jalanb)
- Hitz (hitengajjar)
- David Aronchick (aronchick)
- Alexander Kapustin (dyens)
- Marcelo Huerta (richieadler)
